@@ -12,6 +12,14 @@ class Assign(Program):
     rval: int
 
 
+@dataclass
+class AssignSub(Program):
+    lvar: str
+    routine: str
+    arg1: str
+    arg2: str
+
+
 @dataclass
 class _BinOp(Program):
     lvar: str
